@@ -11,6 +11,8 @@ from .SendToLogzIo import SendTOLogzIo
 from .debug_mode import DebugMode
 from user_context_remote.user_context import UserContext
 from .LoggerOutputEnum import LoggerOutputEnum
+from sdk.src.utilities import validate_enviroment_variables
+
 
 
 logzio_token = os.getenv("LOGZIO_TOKEN")
@@ -22,7 +24,7 @@ loggers={}
 class Logger:
     @staticmethod
     def create_logger(**kwargs):
-        Logger._validate_enviroment_variables()
+        validate_enviroment_variables()
         if('component_id' not in kwargs['object'] or "component_name" not in kwargs['object'] or "component_category" not in kwargs['object'] or "developer_email" not in kwargs['object']):
             raise Exception("please insert component_id, component_name, component_category and developer_email in your object")
         component_id=kwargs['object']['component_id']
@@ -575,16 +577,5 @@ class Logger:
                   sql_query+" Exception=" + str(e), file=sys.stderr)
             return None
     
-    @staticmethod
-    def _validate_enviroment_variables():
-        if(os.getenv("ENVIRONMENT_NAME") is None):
-            raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called ENVIRONMENT_NAME=local or play1 (instead of ENVIRONMENT)")
-        if(os.getenv("PRODUCT_USER_IDENTIFIER") is None):
-            raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called PRODUCT_USER_IDENTIFIER (instead of PRODUCT_USERNAME)")
-        if(os.getenv("PRODUCT_PASSWORD") is None):
-            raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called PRODUCT_PASSWORD")
-        if(os.getenv("LOGZIO_TOKEN") is None):
-            raise Exception("logger-local-python-package LoggerLocal.py please add Environment Variable called LOGZIO_TOKEN=cXNHuVkkffkilnkKzZlWExECRlSKqopE")
-    
 
 
